extern int x;
extern int x234567890;

extern int p();
extern int p234567890();

int n;
int n234567890;

void q() { x = p(); }
void q234567890() { x234567890 = p234567890(); }
